@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.2.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
 
@@ -47,7 +47,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.2"
+#define YYBISON_VERSION "2.3"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -212,7 +212,7 @@ typedef union YYSTYPE
 	char *string;
 	struct strList *strList;
 }
-/* Line 193 of yacc.c.  */
+/* Line 187 of yacc.c.  */
 #line 217 "g15composer.tab.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -543,12 +543,12 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,    93,    93,    94,   104,   108,   109,   110,   111,   112,
-     113,   127,   128,   129,   133,   140,   146,   154,   163,   172,
-     181,   209,   213,   222,   231,   240,   249,   258,   267,   276,
-     294,   311,   313,   315,   319,   328,   337,   346,   355,   364,
-     373,   383,   397,   409,   418,   427,   474,   486,   498,   515,
-     532,   549,   575,   581,   634,   644,   654,   668
+       0,    93,    93,    94,   107,   111,   112,   113,   114,   115,
+     116,   130,   131,   132,   136,   143,   149,   157,   166,   175,
+     184,   212,   216,   225,   234,   243,   252,   261,   270,   279,
+     297,   314,   316,   318,   322,   331,   340,   349,   358,   367,
+     376,   386,   400,   412,   421,   430,   475,   487,   499,   516,
+     533,   550,   576,   582,   636,   647,   658,   672
 };
 #endif
 
@@ -879,13 +879,13 @@ do {									  \
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, const YYSTYPE * const yyvaluep)
+yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
 #else
 static void
 yy_symbol_value_print (yyoutput, yytype, yyvaluep)
     FILE *yyoutput;
     int yytype;
-    const YYSTYPE * const yyvaluep;
+    YYSTYPE const * const yyvaluep;
 #endif
 {
   if (!yyvaluep)
@@ -911,13 +911,13 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, const YYSTYPE * const yyvaluep)
+yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
 #else
 static void
 yy_symbol_print (yyoutput, yytype, yyvaluep)
     FILE *yyoutput;
     int yytype;
-    const YYSTYPE * const yyvaluep;
+    YYSTYPE const * const yyvaluep;
 #endif
 {
   if (yytype < YYNTOKENS)
@@ -965,15 +965,12 @@ do {								\
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_reduce_print (YYSTYPE *yyvsp, 
-		   int yyrule)
+yy_reduce_print (YYSTYPE *yyvsp, int yyrule)
 #else
 static void
-yy_reduce_print (yyvsp, yyrule
-		   )
+yy_reduce_print (yyvsp, yyrule)
     YYSTYPE *yyvsp;
-    
-		   int yyrule;
+    int yyrule;
 #endif
 {
   int yynrhs = yyr2[yyrule];
@@ -1574,13 +1571,16 @@ yyreduce:
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
-		if (((struct parserData *)param)->leaving != 1)
+		if (((struct parserData *)param)->leaving != 1 && ((struct parserData *)param)->cmd_only!=1)
 		  updateScreen (((struct parserData *)param)->canvas, ((struct parserData *)param)->g15screen_fd, 0);
+		else
+		  ((struct parserData *)param)->cmd_only=0;
+
 	}
     break;
 
   case 10:
-#line 114 "g15composer.y"
+#line 117 "g15composer.y"
     {
 		((struct parserData *)param)->itemptr = ((struct parserData *)param)->listptr->first_string;
 		while (((struct parserData *)param)->itemptr != 0)
@@ -1597,21 +1597,21 @@ yyreduce:
     break;
 
   case 14:
-#line 134 "g15composer.y"
+#line 137 "g15composer.y"
     {
 		(yyval.string) = (yyvsp[(1) - (1)].string);
 	}
     break;
 
   case 15:
-#line 140 "g15composer.y"
+#line 143 "g15composer.y"
     {
 		(yyval.strList) = new_strList ();
 	}
     break;
 
   case 16:
-#line 147 "g15composer.y"
+#line 150 "g15composer.y"
     {
 		add_string ((yyvsp[(1) - (2)].strList), (yyvsp[(2) - (2)].string));
 		(yyval.strList) = (yyvsp[(1) - (2)].strList);
@@ -1619,7 +1619,7 @@ yyreduce:
     break;
 
   case 17:
-#line 155 "g15composer.y"
+#line 158 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1628,7 +1628,7 @@ yyreduce:
     break;
 
   case 18:
-#line 164 "g15composer.y"
+#line 167 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1637,7 +1637,7 @@ yyreduce:
     break;
 
   case 19:
-#line 173 "g15composer.y"
+#line 176 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1646,7 +1646,7 @@ yyreduce:
     break;
 
   case 20:
-#line 182 "g15composer.y"
+#line 185 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1674,7 +1674,7 @@ yyreduce:
     break;
 
   case 22:
-#line 214 "g15composer.y"
+#line 217 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1683,7 +1683,7 @@ yyreduce:
     break;
 
   case 23:
-#line 223 "g15composer.y"
+#line 226 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1692,7 +1692,7 @@ yyreduce:
     break;
 
   case 24:
-#line 232 "g15composer.y"
+#line 235 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1701,7 +1701,7 @@ yyreduce:
     break;
 
   case 25:
-#line 241 "g15composer.y"
+#line 244 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1710,7 +1710,7 @@ yyreduce:
     break;
 
   case 26:
-#line 250 "g15composer.y"
+#line 253 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1719,7 +1719,7 @@ yyreduce:
     break;
 
   case 27:
-#line 259 "g15composer.y"
+#line 262 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1728,7 +1728,7 @@ yyreduce:
     break;
 
   case 28:
-#line 268 "g15composer.y"
+#line 271 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1737,7 +1737,7 @@ yyreduce:
     break;
 
   case 29:
-#line 277 "g15composer.y"
+#line 280 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1755,7 +1755,7 @@ yyreduce:
     break;
 
   case 30:
-#line 295 "g15composer.y"
+#line 298 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1773,7 +1773,7 @@ yyreduce:
     break;
 
   case 34:
-#line 320 "g15composer.y"
+#line 323 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1782,7 +1782,7 @@ yyreduce:
     break;
 
   case 35:
-#line 329 "g15composer.y"
+#line 332 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1791,7 +1791,7 @@ yyreduce:
     break;
 
   case 36:
-#line 338 "g15composer.y"
+#line 341 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1800,7 +1800,7 @@ yyreduce:
     break;
 
   case 37:
-#line 347 "g15composer.y"
+#line 350 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1809,7 +1809,7 @@ yyreduce:
     break;
 
   case 38:
-#line 356 "g15composer.y"
+#line 359 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1818,7 +1818,7 @@ yyreduce:
     break;
 
   case 39:
-#line 365 "g15composer.y"
+#line 368 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1827,7 +1827,7 @@ yyreduce:
     break;
 
   case 40:
-#line 374 "g15composer.y"
+#line 377 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1837,7 +1837,7 @@ yyreduce:
     break;
 
   case 41:
-#line 384 "g15composer.y"
+#line 387 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1851,7 +1851,7 @@ yyreduce:
     break;
 
   case 42:
-#line 398 "g15composer.y"
+#line 401 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1863,7 +1863,7 @@ yyreduce:
     break;
 
   case 43:
-#line 410 "g15composer.y"
+#line 413 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1872,7 +1872,7 @@ yyreduce:
     break;
 
   case 44:
-#line 419 "g15composer.y"
+#line 422 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1881,24 +1881,20 @@ yyreduce:
     break;
 
   case 45:
-#line 428 "g15composer.y"
+#line 431 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
-		int fore = ((yyvsp[(2) - (3)].number) == 0 ? 1 : 0);
-		int rear = ((yyvsp[(2) - (3)].number) == 1 ? 1 : 0);
-		int revert = ((yyvsp[(2) - (3)].number) == 2 ? 1 : 0);
-		char msgbuf[1];
 
-		msgbuf[0] = 'v';	/* Is the display visible? */
-		send (((struct parserData *)param)->g15screen_fd, msgbuf, 1, MSG_OOB);
-		recv (((struct parserData *)param)->g15screen_fd, msgbuf, 1, 0);
-		int at_front = (msgbuf[0] != 0 ? 1 : 0);
-		msgbuf[0] = 'u';	/* Did the user make the display visible? */
-		send (((struct parserData *)param)->g15screen_fd, msgbuf, 1, MSG_OOB);
-		recv (((struct parserData *)param)->g15screen_fd, msgbuf, 1, 0);
-		int user_to_front = (msgbuf[0] != 0 ? 1 : 0);
-		msgbuf[0] = 'p';	/* We now want to change the priority */
+                int fore = ((yyvsp[(2) - (3)].number) == 0 ? 1 : 0);
+                int rear = ((yyvsp[(2) - (3)].number) == 1 ? 1 : 0);
+                int revert = ((yyvsp[(2) - (3)].number) == 2 ? 1 : 0);
+                                                                                  
+                int dummy=0;
+                
+                int at_front = g15_send_cmd (((struct parserData *)param)->g15screen_fd, G15DAEMON_IS_FOREGROUND, dummy);
+                int user_to_front = g15_send_cmd(((struct parserData *)param)->g15screen_fd,G15DAEMON_IS_USER_SELECTED, dummy);
+
 		int sendCmd = 0;
 		if (at_front == 1)
 		  {
@@ -1922,13 +1918,15 @@ yyreduce:
 			sendCmd = 1;
 		      }
 		  }
-		if (sendCmd == 1)
-		  send (((struct parserData *)param)->g15screen_fd, msgbuf, 1, MSG_OOB);
+		if (sendCmd == 1){
+		  g15_send_cmd(((struct parserData *)param)->g15screen_fd,G15DAEMON_SWITCH_PRIORITIES,dummy);
+               }
+              ((struct parserData *)param)->cmd_only=1;
 	}
     break;
 
   case 46:
-#line 475 "g15composer.y"
+#line 476 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1940,7 +1938,7 @@ yyreduce:
     break;
 
   case 47:
-#line 487 "g15composer.y"
+#line 488 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1952,7 +1950,7 @@ yyreduce:
     break;
 
   case 48:
-#line 499 "g15composer.y"
+#line 500 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1969,7 +1967,7 @@ yyreduce:
     break;
 
   case 49:
-#line 516 "g15composer.y"
+#line 517 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -1986,7 +1984,7 @@ yyreduce:
     break;
 
   case 50:
-#line 533 "g15composer.y"
+#line 534 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -2003,7 +2001,7 @@ yyreduce:
     break;
 
   case 51:
-#line 550 "g15composer.y"
+#line 551 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -2029,13 +2027,13 @@ yyreduce:
     break;
 
   case 52:
-#line 576 "g15composer.y"
+#line 577 "g15composer.y"
     {
 	}
     break;
 
   case 53:
-#line 582 "g15composer.y"
+#line 583 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
@@ -2082,33 +2080,36 @@ yyreduce:
 		      break;
 		    }
 		  }
+		((struct parserData *)param)->cmd_only=1;
 		if (sendCmd == 1)
 		  send (((struct parserData *)param)->g15screen_fd, &((struct parserData *)param)->mkey_state, 1, MSG_OOB);
 	}
     break;
 
   case 54:
-#line 635 "g15composer.y"
+#line 637 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
-		char msgbuf = G15DAEMON_BACKLIGHT | (yyvsp[(2) - (3)].number);
-		send (((struct parserData *)param)->g15screen_fd, &msgbuf, 1, MSG_OOB);
+	        g15_send_cmd(((struct parserData *)param)->g15screen_fd,G15DAEMON_BACKLIGHT, (yyvsp[(2) - (3)].number));
+		((struct parserData *)param)->cmd_only=1;
+
 	}
     break;
 
   case 55:
-#line 645 "g15composer.y"
+#line 648 "g15composer.y"
     {
 		if (((struct parserData *)param)->background == 1)
 		  return (0);
 		char msgbuf = G15DAEMON_CONTRAST | (yyvsp[(2) - (3)].number);
 		send (((struct parserData *)param)->g15screen_fd, &msgbuf, 1, MSG_OOB);
+		((struct parserData *)param)->cmd_only=1;
 	}
     break;
 
   case 56:
-#line 655 "g15composer.y"
+#line 659 "g15composer.y"
     {
 		struct parserData *newParam = (struct parserData *) malloc (sizeof (struct parserData));
 		newParam->background = 0;
@@ -2122,7 +2123,7 @@ yyreduce:
     break;
 
   case 57:
-#line 669 "g15composer.y"
+#line 673 "g15composer.y"
     {
 		((struct parserData *)param)->leaving = 1;
 	}
@@ -2130,7 +2131,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 2134 "g15composer.tab.c"
+#line 2135 "g15composer.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2339,10 +2340,11 @@ yyreturn:
   if (yymsg != yymsgbuf)
     YYSTACK_FREE (yymsg);
 #endif
-  return yyresult;
+  /* Make sure YYID is used.  */
+  return YYID (yyresult);
 }
 
 
-#line 674 "g15composer.y"
+#line 678 "g15composer.y"
 
 
